#
# spec file for package atkmm1_6
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name   atkmm
Name:           atkmm1_6

Version:        2.28.3
Release:        3.1
Summary:        C++ Binding for the ATK library
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            http://www.gtkmm.org/
Source:         https://download.gnome.org/sources/atkmm/2.28/%{_name}-%{version}.tar.xz
# PATCH-FIX-OPENSUSE atkmm1_6-remove-unnecessary-executable-flag-from-file.patch bsc#1209094 bsc#1209139 qzhao@suse.com -- cancel executable permission for file /usr/share/doc/packages/libatkmm-1_6-1/NEWS
Patch0:         atkmm1_6-remove-unnecessary-executable-flag-from-file.patch

BuildRequires:  c++_compiler
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  graphviz
BuildRequires:  meson >= 0.55.0
BuildRequires:  pkgconfig
BuildRequires:  xsltproc
BuildRequires:  pkgconfig(atk) >= 1.12.0
BuildRequires:  pkgconfig(glibmm-2.4) >= 2.46.2

%description
atkmm is the C++ binding for the ATK library.
This module is part of the GNOME C++ bindings effort.

%package -n libatkmm-1_6-1
Summary:        C++ Binding for the ATK library
License:        LGPL-2.1-or-later
Group:          System/Libraries

%description -n libatkmm-1_6-1
atkmm is the C++ binding for the ATK library.
This module is part of the GNOME C++ bindings effort.

%package devel
Summary:        C++ Binding for the ATK library
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
Requires:       libatkmm-1_6-1 = %{version}

%description devel
atkmm is the C++ binding for the ATK library.
This module is part of the GNOME C++ bindings effort.

%prep
%autosetup -p1 -n %{_name}-%{version}

%build
%meson \
	-Dbuild-documentation=false \
	%{nil}
%meson_build

%install
%meson_install
%fdupes %{buildroot}/%{prefix}

%ldconfig_scriptlets -n libatkmm-1_6-1

%files -n libatkmm-1_6-1
%license COPYING
%doc AUTHORS ChangeLog NEWS README.md
%{_libdir}/libatkmm-1.6.so.*

%files devel
%{_includedir}/atkmm-1.6/
%{_libdir}/libatkmm-1.6.so
%{_libdir}/pkgconfig/atkmm-1.6.pc
%dir %{_libdir}/atkmm-1.6
%{_libdir}/atkmm-1.6/include/
%dir %{_libdir}/atkmm-1.6/proc
%{_libdir}/atkmm-1.6/proc/m4/

%changelog
* Tue Mar  5 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Drop baselibs.conf: the -32bit packages are no longer needed and
  have not been part of Tumbleweed for a while already (build for
  i586 only enabled in LegacyX86).
* Mon Apr 17 2023 qzhao@suse.com
- Add atkmm1_6-remove-unnecessary-executable-flag-from-file.patch:
  cancel executable permission for file
  /usr/share/doc/packages/libatkmm-1_6-1/NEWS
  (bsc#1209094, bsc#1209139).
* Thu Aug 11 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.28.3:
  + Support building with Visual Studio 2022.
  + Meson build:
  - Specify 'check' option in run_command(). Will be necessary
    with future versions of Meson.
  - Perl is not required by new versions of mm-common.
  - Avoid unnecessary configuration warnings.
  - Require meson >= 0.55.0.
  + Require atk >= 2.12.0. Not a new requirement, but previously it
    was not specified in configure.ac and meson.build.
- Changes from version 2.28.2:
  + Meson build:
  - Use relative paths to untracked/.
  - Make it possible to use atkmm as a subproject.
  - No implicit_include_directories.
  + atkmmconfig.h.*: Don't dllimport on MinGW.
- Use ldconfig_scriptlets for post(un) handling.
* Thu Oct  7 2021 pgajdos@suse.com
- turn off doc build, it does not work with new doxygen
* Fri Dec 18 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.28.1:
  + Build:
  - Improve NMake support
  - Use __declspec(dllexport) when building with Visual Studio
  - Add Meson support
  - doc/reference/: Update for Doxygen >= 1.8.16
- Add meson BuildRequires and macros following upstreams port.
- Add doxygen, graphviz and xsltproc  BuildRequires, needed now for
  building documentation.
- Replace gcc-c++ with generic c++_compiler BuildRequires.
- Tweak setup macro and fdupes call.
* Sun Dec  2 2018 bjorn.lie@gmail.com
- Update to version 2.28.0:
  + No changes, version bump only.
- Changes from version 2.24.3:
  + Fix silent builds.
  + Text: Plug memory leaks in get_text_vfunc() and
    get_selection_vfunc(). These vfuncs shall delete the returned
    character array after it has been copied to a Glib::ustring.
  + Replace the Visual Studio project files with MSVC NMake project
    files.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Mon Dec  5 2016 jengelh@inai.de
- rectify rpm groups
* Mon Dec  5 2016 dimstar@opensuse.org
- Rename to atkmm1_6: atkmm 2.25.x brings a new API/ABI to be used
  in GTK4 based applications.
* Fri Apr 15 2016 idonmez@suse.com
- Update to GNOME 3.20  Fate#318572
* Mon Nov 30 2015 zaitor@opensuse.org
- Update to version 2.24.2:
  + Regenerate with the latest glibmm.
* Wed Sep 30 2015 zaitor@opensuse.org
- Update to version 2.24.1:
  + Regenerate with the latest glibmm.
- Changes from version 2.24.0:
  + MSVC build fixes.
* Fri Sep  4 2015 zaitor@opensuse.org
- Update to version 2.23.3:
  + Rebuilt with latest glibmm, whose gmmproc generates C++ move
    operations.
* Sat Jul 25 2015 zaitor@opensuse.org
- Update to version 2.23.2:
  + Use (and require) C++11.
- Changes from version 2.23.1:
  + Atk:
  - Document: Add get/set_attribute() and deprecate
    get_document() and get_document_type().
  - Component: Deprecate add/remove_focus_handler, get_size() and
    get_position().
  - Add Range.
  - Table:
    . Deprecate get_column/row_at_index().
    . Add a get_at() const version and deprecate get_index_at().
  - Text:
    . Deprecate get_text_before_offset(),
    get_text_after_offset().
    . Add get_string_at_offset(), deprecating other methods for
    it.
  - Value: Deprecate get_minimum/maximum_range() in favour or
    get_range().
  + Build: Update MSVC 2005, 2008 and 2010 Projects: Add "Install"
    Project.
* Mon Apr 29 2013 dimstar@opensuse.org
- Update to version 2.22.7:
  + Remove the use of g_type_init() because it has been deprecated.
* Fri Feb  1 2013 coolo@suse.com
- update license to new format
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Tue Nov 15 2011 vuntz@opensuse.org
- Update to version 2.22.6:
  + Add #includes needed with the latest glibmm.
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
- Add atkmm-devel to baselibs
* Thu Jul  7 2011 vuntz@opensuse.org
- Stop using source service to download the tarball, as Factory
  will move away from this.
* Sat Apr 30 2011 dimstar@opensuse.org
- Update to version 2.22.5:
  + bgo#645669: Install the m4 files even without
  - -enable-maintainer-mode, as with other modules.
- Use source services: download_url and set_version.
* Wed Mar 23 2011 fcrozat@novell.com
- Update to version 2.22.4:
  + Avoid a tarball dependency on mm-common.
- Changes from version 2.22.3:
  + a tarball regeneration due to a changed m4 macro in mm-common.
* Sun Jan  9 2011 vuntz@opensuse.org
- Update to version 2.22.2:
  + Install m4 files needed by recent versions of gtkmm when
    building from git.
* Tue Dec  7 2010 vuntz@opensuse.org
- Update to version 2.22.1:
  + Distribute the GPL in the tarball, in addition to the LGPL,
    because the Windows build uses a GPL builder tool.
* Mon Sep 27 2010 vuntz@opensuse.org
- Update to version 2.22.0:
  + Just increased version to show that it's an API/ABI-stable
    release.
* Fri Aug  6 2010 vuntz@opensuse.org
- Initial package: the code got split from gtkmm2.
